package com.example.javacodegeeks.springjavaconfigapi.controller;

import com.example.javacodegeeks.springjavaconfigapi.ActorNotFoundException;
import com.example.javacodegeeks.springjavaconfigapi.model.Actor;
import com.example.javacodegeeks.springjavaconfigapi.repository.ActorRepository;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
public class ActorController {
    private final ActorRepository repository;

    public ActorController(ActorRepository repository) {
        this.repository = repository;
    }

    @PostMapping("/actors")
    Actor newActor(@RequestBody Actor newActor) {
        return repository.save(newActor);
    }

    // All
    @GetMapping("/actors")
    List<Actor> all() {
        return repository.findAll();
    }

    // Single
    @GetMapping("/actors/{id}")
    Actor one(@PathVariable Long id) {
        return repository.findById(id)
                .orElseThrow(() -> new ActorNotFoundException(id));
    }

    @PutMapping("/actors/{id}")
    Actor updateActor(@RequestBody Actor newActor, @PathVariable Long id) {
        return repository.findById(id)
                .map(employee -> {
                    employee.setName(newActor.getName());
                    employee.setRole(newActor.getRole());
                    return repository.save(employee);
                })
                .orElseGet(() -> {
                    newActor.setId(id);
                    return repository.save(newActor);
                });
    }

    @DeleteMapping("/actors/{id}")
    void deleteActor(@PathVariable Long id) {
        repository.deleteById(id);
    }
}
